function [Co,Ma,G] = matbin(Bm,mod)

%        [Co,Ma,G] = matbin(Bm,mod)
%
% For a matrix Bm with entries 0 and 1 indicating the marginal
% effects (mod = 'mar') or the loglinear ones (mode = 'log'),
% provides the corresponding matrix of constrats Co, that of
% aggregation Ma and the design matrix of the corresponding
% log-linear model 

% adjust input
  if nargin<2,
    mod = 'mar';
  end
% construct matrices
  [ne,J] = size(Bm);
  Co = []; Ma = []; G = [];
  for i = 1:ne,
    Coi = 1; Mai = 1; Gi = 1;
    for j = 1:J,
      if Bm(i,j),
        Coi = kron(Coi,[-1 1]);
        Mai = kron(Mai,eye(2));
        Gi = kron(Gi,[-1 1]'/2);
      else
        if mod == 'mar',
          Mai = kron(Mai,[1 1]);
        elseif mod == 'log',
          Mai = kron(Mai,[1 0]);
        end
        Gi = kron(Gi,[1 1]');
      end
    end
    Co = blkdiag(Co,Coi);
    Ma = [Ma; Mai];
    G = [G Gi];
  end