function n0 = lkrcond(N,Ya,Psi,ind)

%        n0 = lkrcond(N,Ya,Psi,ind)  
%
% find the optimal configuration n0 for the missing cell
% for the conditional confidence interval
% N is the population total, Ya the observed table 
% Psi matrix of probabilities of the same dimension of Ya
% ind (optional): vector of indices of the strata whose size
%                 has to be summed up to obtain N

% Preliminaries
  if nargin<4,
    ind = (1:size(Ya,1));
  end
  if sum(Ya(ind))==N,
    n0 = zeros(size(Ya,1),1);
    return
  end
% Maximization
  Y = Ya; S = size(Y,1);
  C = zeros(1,S); C(ind) = 1;
  D = eye(S);
  p0 = Psi(:,1); 
  n = sum(Y(:,2:end),2); 
  if sum(Y(ind,1))==0,
    n0 = n.*p0./(1-p0); n0 = n0/sum(n0(ind))*(N-sum(n(ind)));
  else
    n0 = Y(:,1)/sum(Y(ind,1))*(N-sum(n(ind)));
  end
  Y(:,1) = n0; yt = n+n0;
  Yh = diagv(yt,Psi);
  G2 = -2*sum(sum(Y.*log(max(Y,eps)./Yh))); G2o = G2-10^10;
  disp(G2);
  while abs(G2-G2o)/abs(G2)>10^-8;
    d1 = -2*log(n0./(yt.*p0));
    d2 = -2*n./(n0.*yt);
    n0 = lsde(n0-d1./d2,C,D,-diag(d2),N-sum(n(ind)),zeros(S,1));
    Y(:,1) = n0; yt = n+n0;
    Yh = diagv(yt,Psi);
    G2o = G2; G2 = -2*sum(sum(Y.*log(max(Y,eps)./Yh)));
    disp([G2 G2-G2o]);
  end